# czekitout

[![Test library](https://github.com/mrfitzpa/czekitout/actions/workflows/test_library.yml/badge.svg)](https://github.com/mrfitzpa/czekitout/actions/workflows/test_library.yml)
[![Code Coverage](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/mrfitzpa/03df7baa137bcac859f4cb8927a62a23/raw/czekitout_coverage_badge.json)](https://github.com/mrfitzpa/czekitout/actions/workflows/measure_code_coverage.yml)
[![Documentation](https://img.shields.io/badge/docs-read-brightgreen)](https://mrfitzpa.github.io/czekitout)
[![PyPi Version](https://img.shields.io/pypi/v/czekitout.svg)](https://pypi.org/project/czekitout)
[![Conda-Forge Version](https://img.shields.io/conda/vn/conda-forge/czekitout.svg)](https://anaconda.org/conda-forge/czekitout)
[![License](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

`czekitout` is a Python library that contains a collection of functions that
facilitate validation, and type-conversions, with useful error messages when
exceptions are thrown.

Visit the `czekitout`
[website](https://mrfitzpa.github.io/czekitout) for a web
version of the installation instructions, the reference guide, and the examples
archive.

<!--
For those reading raw .rst files, see file `docs/INSTALL.rst` for
instructions on installing the `czekitout` library.
-->